@@ -662,6 +662,10 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 * @returns true if sign is pre signal (distant signal)
 	 */
 	register_method(vm, &roadsign_desc_t::is_pre_signal, "is_pre_signal");
+	/**
+	 * @returns true if sign is priority signal
+	 */
+	register_method(vm, &roadsign_desc_t::is_priority_signal, "is_priority_signal");
 	/**
 	 * @returns true if sign is long-block signal
 	 */
