@@ -59,7 +59,7 @@ city_info_t::city_info_t(stadt_t* city) :
 
 	// add city name input field
 	name_input.set_pos(scr_coord(D_MARGIN_LEFT, D_MARGIN_TOP));
-	name_input.set_size(scr_size(2*D_BUTTON_WIDTH, D_BUTTON_HEIGHT));
+	name_input.set_size(scr_size(2*D_BUTTON_WIDTH, D_EDIT_HEIGHT));
 	name_input.add_listener( this );
 	add_component(&name_input);
 
@@ -138,19 +138,27 @@ void city_info_t::resize(const scr_coord delta)
 
 	if(  world_aspect/space_aspect > PAX_DEST_VERTICAL  ) { // world wider than space, use vertical minimap layout
 		minimaps_size.h = (space.y - D_V_SPACE) / 2;
-		minimaps_size.w = (sint16) ((float)minimaps_size.h * world_aspect);
-		if(  minimaps_size.w  > space.x  ) {
+		if(  minimaps_size.h * world_aspect <= space.x) {
+			// minimap fits
+			minimaps_size.w = (sint16) (minimaps_size.h * world_aspect);
+		}
+		else {
+			// too large, truncate
 			minimaps_size.w = space.x;
-			minimaps_size.h = max((int)((float)minimaps_size.w / world_aspect), PAX_DEST_MIN_SIZE);
+			minimaps_size.h = max((int)(minimaps_size.w / world_aspect), PAX_DEST_MIN_SIZE);
 		}
 		minimap2_offset = scr_coord( 0, minimaps_size.h + D_V_SPACE );
 	}
 	else { // horizontal minimap layout
 		minimaps_size.w = (space.x - D_H_SPACE) / 2;
-		minimaps_size.h = (sint16) ((float)minimaps_size.w / world_aspect);
-		if(  minimaps_size.h > space.y  ) {
+		if (minimaps_size.w / world_aspect <= space.y) {
+			// minimap fits
+			minimaps_size.h = (sint16) (minimaps_size.w / world_aspect);
+		}
+		else {
+			// too large, truncate
 			minimaps_size.h = space.y;
-			minimaps_size.w = max((int)((float)minimaps_size.h * world_aspect), PAX_DEST_MIN_SIZE);
+			minimaps_size.w = max((int)(minimaps_size.h * world_aspect), PAX_DEST_MIN_SIZE);
 		}
 		minimap2_offset = scr_coord( minimaps_size.w + D_H_SPACE, 0 );
 	}
@@ -310,7 +318,7 @@ void city_info_t::draw(scr_coord pos, scr_size size)
 	buf.append( c->get_homeless(), 0 );
 
 	display_multiline_text_rgb(pos.x + D_MARGIN_LEFT,
-		pos.y+D_TITLEBAR_HEIGHT + D_MARGIN_TOP+D_BUTTON_HEIGHT+D_V_SPACE, buf, SYSCOL_TEXT );
+		pos.y+D_TITLEBAR_HEIGHT + D_MARGIN_TOP+D_EDIT_HEIGHT+D_V_SPACE, buf, SYSCOL_TEXT );
 
 	const uint32 current_pax_destinations = c->get_pax_destinations_new_change();
 	if(  pax_destinations_last_change > current_pax_destinations  ) {
@@ -466,7 +474,7 @@ city_info_t::city_info_t() :
 	const int window_height = D_TITLEBAR_HEIGHT + D_MARGIN_TOP + D_BUTTON_HEIGHT + D_V_SPACE +
 		8*LINESPACE + D_V_SPACE + D_CHECKBOX_HEIGHT + D_V_SPACE + MIN_CHART_HEIGHT + 2*(D_BUTTON_HEIGHT + D_V_SPACE);
 
-	set_min_windowsize(scr_size(D_MARGIN_LEFT + 5*D_BUTTON_WIDTH + 4*D_H_SPACE + D_MARGIN_RIGHT, window_height));
+	set_min_windowsize(scr_size(D_DEFAULT_WIDTH, window_height));
 	set_resizemode(diagonal_resize);
 }
 
