@@ -11,6 +11,7 @@
 #include "components/gui_label.h"
 #include "components/gui_button.h"
 #include "components/gui_numberinput.h"
+#include "components/gui_combobox.h"
 
 #define COLORS_MAX_BUTTONS (26)
 #define BUF_MAXLEN_MS_FORMAT (16)
@@ -54,6 +55,9 @@ private:
 		divider3,
 		divider4;
 
+	gui_combobox_t
+		money_booking;
+
 	gui_container_t
 		label_container,
 		value_container;
