@@ -37,6 +37,7 @@ bool env_t::easy_server = false;
 sint32 env_t::server_announce_interval = 900;
 int env_t::server_port = 13353;
 std::string env_t::server_dns;
+std::string env_t::server_alt_dns; // for dualstack systems
 std::string env_t::server_name;
 std::string env_t::server_comments;
 std::string env_t::server_email;
@@ -133,6 +134,7 @@ sint8 env_t::daynight_level;
 bool env_t::left_to_right_graphs;
 uint32 env_t::tooltip_delay;
 uint32 env_t::tooltip_duration;
+sint8 env_t::show_money_message;
 
 std::string env_t::fontname = FONT_PATH_X "prop.fnt";
 uint8 env_t::fontsize = 11;
@@ -269,6 +271,7 @@ void env_t::init()
 	// Listen on all addresses by default
 	listen.append_unique("::");
 	listen.append_unique("0.0.0.0");
+	show_money_message = 0;
 }
 
 
@@ -465,5 +468,8 @@ void env_t::rdwr(loadsave_t *file)
 		}
 		file->rdwr_byte( fontsize );
 	}
+	if(  file->get_version()>=120007  ) {
+		file->rdwr_byte(show_money_message);
+	}
 	// server settings are not saved, since they are server specific and could be different on different servers on the save computers
 }
