@@ -3,8 +3,9 @@
 
 #include "../simtypes.h"
 
-struct font_type
+class font_t
 {
+public:
 	char fname[1024];
 	sint16	height;
 	sint16	descent;
@@ -12,11 +13,16 @@ struct font_type
 	uint8 *screen_width;
 	uint8 *char_data;
 
-	font_type()
+	enum fonttype { BINARY=1, BDF=2, FREETYPE=3 };
+
+	font_t()
 	: height(0), descent(0), num_chars(0), screen_width(NULL), char_data(NULL)
 	{
 		fname[0]= 0;
 	}
+
+	// later we may add on the fly rendering for freefont
+	uint16 get_char(uint16 i) { return char_data[i] == 0 ? 0 : i; }
 };
 
 /*
@@ -32,6 +38,6 @@ struct font_type
 /**
  * Loads a font
  */
-bool load_font(font_type* font, const char* fname);
+bool load_font(font_t* font, const char* fname);
 
 #endif
