@@ -33,30 +33,6 @@ const int totalslopes = 81;
 #define blue_comp(pix)         ((pix)&0x001f)
 
 
-/*  mixed_color
-	this uses pixel map to produce an pixel from pixels src1, src2 and src3
-	src1 uses the red component of map
-	src2 uses the green component of map
-	src3 uses the blue component of map
-*/
-/*static PIXVAL mixed_color(PIXVAL map, PIXVAL src1, PIXVAL src2, PIXVAL src3)
-{
-	if(map!=0) {
-		uint16 rc = red_comp(map);
-		uint16 gc = green_comp(map);
-		uint16 bc = blue_comp(map);
-
-		// overflow safe method ...
-		uint16 rcf = (rc*red_comp(src1) + gc*red_comp(src2) + bc*red_comp(src3) )/(rc+gc+bc);
-		uint16 gcf = (rc*green_comp(src1) + gc*green_comp(src2) + bc*green_comp(src3) )/(rc+bc+gc);
-		uint16 bcf = (rc*blue_comp(src1) + gc*blue_comp(src2) + bc*blue_comp(src3) )/(rc+gc+bc);
-
-		return (bcf)|(gcf<<5)|(rcf<<10);
-	}
-	return 0;
-} */
-
-
 /* combines a texture and a lightmap
  * just weights all pixels by the lightmap
  */
@@ -111,158 +87,6 @@ static image_t* create_textured_tile(const image_t* image_lightmap, const image_
 }
 
 
-/* combines a texture and a lightmap
- * does a very simple stretching of the texture and the mix images
- * BEWARE: Assumes all images but image_lightmap are square!
- * BEWARE: no special colors or your will see literally blue!
- */
-/*static image_t* create_textured_tile_mix(const image_t* image_lightmap, slope_t::type slope, const image_t* image_mixmap,  const image_t* image_src1, const image_t* image_src2, const image_t* image_src3)
-{
-	image_t *image_dest = image_lightmap->copy_rotate(0);
-#if COLOUR_DEPTH != 0
-	PIXVAL const* const mixmap  = image_mixmap->get_data();
-	PIXVAL const* const src1    = image_src1->get_data() - image_src1->get_pic()->y * (image_src1->get_pic()->w + 3L);
-	PIXVAL const* const src2    = image_src2->get_data() - image_src2->get_pic()->y * (image_src2->get_pic()->w + 3L);
-	PIXVAL const* const src3    = image_src3->get_data() - image_src3->get_pic()->y * (image_src3->get_pic()->w + 3L);
-	sint32        const x_y     = image_src1->get_pic()->w;
-	sint32        const mix_x_y = image_mixmap->get_pic()->w;
-	sint16 tile_x, tile_y;
-
-*/	/*
-	* to go from mixmap xy to tile xy is simple:
-	* (x,y)_tile = (mixmap_x+mixmap_y)/2 , (mixmap_y-mixmap_x)/4+(3/4)*tilesize
-	* This is easily inverted to
-	* (x,y)mixmap = x_tile-2*y_tile+(3/2)*tilesize, x_tile+2*y_tile-(3/2)*tilesize
-	* tricky are slopes. There we have to add an extra distortion
-	* /4\
-	* 1+3
-	* \2/
-	* Luckily this distortion is only for the y direction.
-	* for corner 1: max(0,(tilesize-(x+y))*HEIGHT_STEP)/tilesize )
-	* for corner 2: max(0,((y-x)*HEIGHT_STEP)/tilesize )
-	* for corner 3: max(0,((x+y)-tilesize)*HEIGHT_STEP)/tilesize )
-	* for corner 4: max(0,((x-y)*HEIGHT_STEP)/tilesize )
-	* the maximum operators make the inversion of the above equation nearly impossible.
-	*/
-
-/*	// we will need them very often ...
-	const sint16 corner_sw_y = (3*x_y)/4 - corner_sw(slope)*tile_raster_scale_y(TILE_HEIGHT_STEP,x_y);
-	const sint16 corner_se_y = x_y - corner_se(slope)*tile_raster_scale_y(TILE_HEIGHT_STEP,x_y);
-	const sint16 corner_ne_y = (3*x_y)/4 - corner_ne(slope)*tile_raster_scale_y(TILE_HEIGHT_STEP,x_y);
-	const sint16 corner_nw_y = (x_y/2) - corner_nw(slope)*tile_raster_scale_y(TILE_HEIGHT_STEP,x_y);
-	const sint16 middle_y = (corner_se_y+corner_nw_y)/2;
-
-	// now mix the images
-	PIXVAL* dest = image_dest->get_data();
-	for (int j = 0; j < image_dest->get_pic()->h; j++) {
-		tile_y = image_dest->get_pic()->y + j;
-		tile_x = *dest++;
-		// offset is the pixel position in the mixmap bitmaps;
-		// so we can avoid stretching the mixmaps
-		const sint32 offset = (image_dest->get_pic()->y + j) * (x_y + 3) + 2;
-		do
-		{
-			sint16 runlen = *dest++;
-			for(int i=0; i<runlen; i++) {
-				// now we must calculate the target pixel
-				// after the upper explanation, you will understand this is longish:
-				sint16 tile_y_corrected;
-
-				// first; check, if we are front or back half
-				// back half means, we are above a line from the left_y (corner_sw), middle_y, right_y (corner_se)
-				const sint16 back_y = (tile_x<x_y/2) ? corner_sw_y + ((middle_y-corner_sw_y)*tile_x)/(x_y/2) : middle_y + ((corner_ne_y-middle_y)*(tile_x-(x_y/2)))/(x_y/2);
-				// in the middle? then it is just the diagonal in the mixmap
-				if(back_y==tile_y) {
-					tile_y_corrected = 0;
-				}
-				else if(back_y>tile_y) {
-					// left quadrant calulation: mirror of right quadrat
-					sint16 x = tile_x;
-					if(x>=x_y/2) {
-						x = x_y-tile_x;
-					}
-					// we are in the back tile => calculate border y
-					sint16 backborder_y;
-					if(tile_x>x_y/2) {
-						backborder_y = corner_nw_y + ((corner_ne_y-corner_nw_y)*(x_y/2-x))/(x_y/2);
-					}
-					else {
-						backborder_y = corner_sw_y + ((corner_nw_y-corner_sw_y)*x)/(x_y/2);
-					}
-					// ok, now we have to calculate the y coordinate ...
-					if(backborder_y<tile_y) {
-						tile_y_corrected = -((back_y-tile_y)*x)/(back_y - backborder_y);
-					}
-					else {
-						tile_y_corrected = -x;
-					}
-				}
-				else {
-					// left quadrant calulation: mirror of right quadrat
-					sint16 x = tile_x;
-					if(x>=x_y/2) {
-						x = x_y-tile_x;
-					}
-					// we are in the front tile => calculate border y
-					sint16 frontborder_y;
-					if(tile_x>x_y/2) {
-						frontborder_y = corner_se_y + ((corner_ne_y-corner_se_y)*(x_y/2-x))/(x_y/2);
-					}
-					else {
-						frontborder_y = corner_sw_y + ((corner_se_y-corner_sw_y)*x)/(x_y/2);
-					}
-					// ok, now we have to calculate the y coordinate ...
-					if(frontborder_y>tile_y) {
-						tile_y_corrected = -((back_y-tile_y)*x)/(frontborder_y-back_y);
-					}
-					else {
-						tile_y_corrected = x;
-					}
-				}
-
-				// now we have calulated the y_t of square tile that is rotated by 45 degree
-				// so we just have to do a 45 deg backtransform ...
-				// (and do not forget: tile_y_corrected middle = 0!
-				sint16 x_t = tile_x - tile_y_corrected;
-				sint16 y_t = tile_y_corrected+tile_x;
-				// due to some inexactness of interger arithmethics, we have to take care of overflow
-				if(y_t>=x_y) {
-					y_t = x_y-1;
-				}
-				if(x_t>=x_y) {
-					x_t = x_y-1;
-				}
-				sint32 mixmap_offset = ( (y_t*mix_x_y) / x_y) *(mix_x_y+3) + 2 + (x_t * mix_x_y)/x_y;
-
-				PIXVAL mix = mixed_color(mixmap[mixmap_offset],src1[offset+tile_x],src2[offset+tile_x],src3[offset+tile_x]);
-				// to see only the mixmap for mixing, uncomment next line
-//				PIXVAL mix = mixmap[mixmap_offset];
-				PIXVAL grey = *dest;
-				PIXVAL rc = (red_comp(grey)*red_comp(mix))/16;
-				// just avoid overflow
-				if(rc>=32) {
-					rc = 31;
-				}
-				PIXVAL gc = (green_comp(grey)*green_comp(mix))/16;
-				if(gc>=32) {
-					gc = 31;
-				}
-				PIXVAL bc = (blue_comp(grey)*blue_comp(mix))/16;
-				if(bc>=32) {
-					bc = 31;
-				}
-				*dest++ = (rc<<10) | (gc<<5) | bc;
-				tile_x ++;
-			}
-			tile_x += *dest;
-		} while(  *dest++!=0 );
-	}
-#endif
-	image_dest->register_image();
-	return image_dest;
-} */
-
-
 /* combines a texture and a lightmap
  * does a very simple stretching of the texture and the mix images
  * BEWARE: Assumes all images but image_lightmap are square!
