@@ -34,7 +34,7 @@ static bool compare_fussgaenger_desc(const pedestrian_desc_t* a, const pedestria
 bool pedestrian_t::register_desc(const pedestrian_desc_t *desc)
 {
 	if(  table.remove(desc->get_name())  ) {
-		dbg->warning( "pedestrian_t::register_desc()", "Object %s was overlaid by addon!", desc->get_name() );
+		dbg->doubled( "pedestrian", desc->get_name() );
 	}
 	table.put(desc->get_name(), desc);
 	return true;
