@@ -18,6 +18,8 @@
 #include "macros.h"
 #include "simmain.h"
 #include "simsys.h"
+#include "pathes.h"
+#include "simevent.h"
 
 
 #ifdef _WIN32
@@ -343,7 +345,7 @@ char const *dr_query_homedir()
 		return NULL;
 	}
 
-	// Append Sumutrans folder.
+	// Append Simutrans folder.
 	char const foldername[] = "Simutrans";
 	if(lengthof(buffer) < strlen(buffer) + strlen(foldername) + 2 * strlen(PATH_SEPARATOR) + 1){
 		return NULL;
@@ -363,10 +365,6 @@ char const *dr_query_homedir()
 	// create directory and subdirectories
 	dr_mkdir(buffer);
 	strcat(buffer, PATH_SEPARATOR);
-	dr_chdir(buffer);
-	dr_mkdir("maps");
-	dr_mkdir("save");
-	dr_mkdir("screenshots");
 
 	return buffer;
 }
