@@ -12,9 +12,10 @@
 #include "display/simgraph.h"
 
 // ticker height
-#define TICKER_HEIGHT      (LINESPACE+3)
+#define TICKER_HEIGHT (LINESPACE+3)
+
 // ticker vertical position from bottom of screen
-#define TICKER_YPOS_BOTTOM (15+TICKER_HEIGHT)
+extern uint16 TICKER_YPOS_BOTTOM;
 
 class koord;
 
