@@ -134,7 +134,9 @@ void wayobj_t::rdwr(loadsave_t *file)
 	xml_tag_t t( file, "wayobj_t" );
 	obj_t::rdwr(file);
 	if(file->get_version()>=89000) {
-		file->rdwr_byte(dir);
+		uint8 ddir = dir;
+		file->rdwr_byte(ddir);
+		dir = ddir;
 		if(file->is_saving()) {
 			const char *s = desc->get_name();
 			file->rdwr_str(s);
@@ -163,7 +165,7 @@ void wayobj_t::rdwr(loadsave_t *file)
 	}
 	else {
 		desc = default_oberleitung;
-		dir = 255;
+		dir = dir_unknown;
 	}
 }
 
@@ -190,7 +192,7 @@ const char *wayobj_t::is_deletable(const player_t *player)
 void wayobj_t::finish_rd()
 {
 	// (re)set dir
-	if(dir==255) {
+	if(dir==dir_unknown) {
 		const waytype_t wt = (desc->get_wtyp()==tram_wt) ? track_wt : desc->get_wtyp();
 		weg_t *w=welt->lookup(get_pos())->get_weg(wt);
 		if(w) {
@@ -278,7 +280,7 @@ void wayobj_t::calc_image()
 		}
 
 		ribi_t::ribi sec_way_ribi_unmasked = 0;
-		if (wt == any_wt) {
+		if(wt == any_wt) {
 			if (weg_t *sec_w = gr->get_weg_nr(1)) {
 				sec_way_ribi_unmasked = sec_w->get_ribi_unmasked();
 			}
@@ -439,10 +441,8 @@ bool wayobj_t::successfully_loaded()
 bool wayobj_t::register_desc(way_obj_desc_t *desc)
 {
 	// avoid duplicates with same name
-	const way_obj_desc_t *old_desc = table.get(desc->get_name());
-	if(old_desc) {
-		dbg->warning( "wayobj_t::register_desc()", "Object %s was overlaid by addon!", desc->get_name() );
-		table.remove(desc->get_name());
+	if(  const way_obj_desc_t *old_desc = table.remove(desc->get_name())  ) {
+		dbg->doubled( "wayobj", desc->get_name() );
 		tool_t::general_tool.remove( old_desc->get_builder() );
 		delete old_desc->get_builder();
 		delete old_desc;
